@@ -7,7 +7,7 @@ Why does this file exist, and why __main__? For more info, read:
 - https://docs.python.org/3/using/cmdline.html#cmdoption-m
 """
 
-from autojob.cli import main
+from autojob._cli import main
 
 if __name__ == "__main__":
     main.main()
