@@ -17,7 +17,6 @@ from uuid import uuid4
 
 from ase import Atoms
 from ase.calculators.calculator import Calculator
-from ase.calculators.calculator import get_calculator_class
 import ase.io
 import shortuuid
 
@@ -394,10 +393,9 @@ class Coordinator:
         return calculator_type
 
     @property
-    def ase_calculator(self) -> Calculator:
+    def calculator(self) -> Calculator:
         """The ASE calculator corresponding to the calculator type."""
-        calculator = get_calculator_class(self.calculator_type.lower())
-        return calculator
+        return self.calculator_type.lower()
 
     def calc_param_from(
         self, param_name: str, cp_groups: list[str] | None = None
@@ -613,7 +611,7 @@ class Coordinator:
         tasks: list[TaskBase] = []
         for calc_params in calculation_parameter_sets:
             calculation_inputs = CalculationInputs(
-                ase_calculator=self.ase_calculator,
+                calculator=self.calculator,
                 run_bader=False,
                 run_chargemol=False,
                 parameters=calc_params,
@@ -668,33 +666,28 @@ class Coordinator:
         )
         return tasks
 
-    def create_study_group(self, *, legacy_mode: bool = True) -> StudyGroup:
+    def create_study_group(self) -> StudyGroup:
         """Create a study group from the Coordinator GUI.
 
-        Args:
-            legacy_mode: Whether or not to use the legacy directory structure
-                when creating task directories. Defaults to True.
-
         Returns:
             The created :class:`~autojob.study_group.StudyGroup`.
         """
-        study_group_id = "g" + shortuuid.uuid()[:9] if legacy_mode else uuid4()
+        # Extract study group name and notes from GUI
+        study_group = StudyGroup()
         studies: list[Study] = []
 
         for name, structure_group in self.structure_groups.items():
-            study_id = "s" + shortuuid.uuid()[:9] if legacy_mode else uuid4()
+            study = Study(
+                study_group_id=study_group.study_group_id,
+                name=name,
+            )
             tasks: list[TaskBase] = []
             task_metadata = {
-                "Study Group ID": study_group_id,
-                "Study ID": study_id,
+                "study_group_id": study_group.study_group_id,
+                "study_id": study.study_id,
             }
             calculation_parameter_sets = self.calc_params[name].get_sets()
 
-            if legacy_mode:
-                task_metadata["Calculation Type"] = self.calculation_type
-                task_metadata["Calculator Type"] = self.calculator_type
-                task_metadata["Study Type"] = self.study_type
-
             for structure in structure_group.structures:
                 atoms = ase.io.read(structure)
 
@@ -707,33 +700,20 @@ class Coordinator:
                         atoms=atoms,
                         calculation_parameter_sets=calculation_parameter_sets,
                         metadata=task_metadata,
-                        legacy_mode=legacy_mode,
                     )
                 )
+            study.tasks += tasks
 
-            study = Study(
-                tasks=tasks,
-                study_id=study_id,
-                study_group_id=study_group_id,
-                name=name,
-                study_type=self.study_type if legacy_mode else None,
-            )
             studies.append(study)
 
-        study_group = StudyGroup(
-            studies=studies, study_group_id=study_group_id, name=""
-        )
+        study_group.studies += studies
         return study_group
 
-    def create_tasks(self, *, legacy_mode: bool = True) -> Path:
-        """Create the task directories of a study group.
-
-        Args:
-            legacy_mode: Whether or not to use legacy mode. Defaults to True.
-        """
-        study_group = self.create_study_group(legacy_mode=legacy_mode)
-        dir_name = self.submit_dir.joinpath(str(study_group.study_group_id))
-        study_group.to_directory(dir_name, legacy_mode=legacy_mode)
+    def create_tasks(self) -> Path:
+        """Create the task directories of a study group."""
+        study_group = self.create_study_group()
+        dir_name = self.submit_dir
+        study_group.to_directory(dir_name)
         return dir_name
 
     def run_jobs(self) -> None:
