@@ -34,6 +34,7 @@ from autojob import SETTINGS
 from autojob.utils import parsing
 from autojob.utils.files import create_job_stats_file
 from autojob.utils.files import get_slurm_job_id
+from autojob.utils.parsing import convert
 from autojob.utils.schemas import hyphenate
 
 logger = logging.getLogger(__name__)
@@ -44,38 +45,6 @@ MEMORY_RE = r"^(?P<memory>[0-9.]+)(?P<units>[A-Za-z]*)$"
 _memory_keys = ["mem", "mem_per_cpu"]
 
 
-def convert(memory: float, from_units: str, to_units: str) -> float:
-    """Convert memory denominations in binary.
-
-    Units can be specified using uppercase, lowercase, one-, or two-letter
-    abbreviations.
-    E.g., 'K', 'k', 'KB', 'kb' are all interpreted as kilobytes.
-
-    Args:
-        memory (float): memory to be converted.
-        from_units (str): The units from which memory is to be converted.
-        to_units (str): The units to which memory is to be converted.
-
-    Returns:
-        float: The memory in the desired units.
-    """
-    factor = _determine_conversion_factor(units=from_units)
-    divisor = _determine_conversion_factor(units=to_units)
-
-    return (factor / divisor) * memory
-
-
-def _determine_conversion_factor(units: str) -> float:
-    prefixes = ["", "k", "m", "g", "t"]
-    units = units.lower().rstrip("b")
-    try:
-        exponent = prefixes.index(units)
-        return 1e3**exponent
-    except ValueError as err:
-        msg = f"Unknown units specified: {units}"
-        raise ValueError(msg) from err
-
-
 def validate_memory(
     v: Any,
     handler: ValidatorFunctionWrapHandler,
@@ -344,10 +313,13 @@ class SchedulerInputs(BaseModel):
         description="The memory requested per cpu in MB.",
     )
     nodes: int | None = None
-    cores_per_node: int | None = Field(
+    ntasks_per_node: int | None = Field(
         default=None,
-        description="The number of cores per node",
-        alias="ntasks-per-node",
+        description="The number of tasks per node",
+    )
+    cpus_per_task: int | None = Field(
+        default=None,
+        description="The number of CPUs per task",
     )
     time: Time | None = Field(
         default=None,
@@ -614,7 +586,7 @@ class SchedulerOutputs(BaseModel):
     job_id: int | None = None
     max_rss: Memory | None = Field(
         default=None,
-        description="Maximum memory used by job.",
+        description="Maximum memory used by job in KB.",
     )
     nodes: list[str] = Field(
         default=[],
@@ -635,6 +607,8 @@ class SchedulerOutputs(BaseModel):
         cls, v: Any, handler: ValidatorFunctionWrapHandler, _: ValidationInfo
     ) -> JobState:
         """Validate the job state from the value or name of a JobState."""
+        if v is None:
+            return JobState.UNKNOWN
         try:
             handler(v)
         except ValidationError:
@@ -735,3 +709,14 @@ def get_scheduler_command(scheduler: str) -> str:
             msg = f"Scheduler {scheduler} is not supported"
             raise ValueError(msg)
     return cmd
+
+
+class ScheduledMixin:
+    """A mixin class for scheduled tasks."""
+
+    scheduler_inputs: SchedulerInputs = Field(
+        default_factory=SchedulerInputs, description="The scheduler intputs"
+    )
+    scheduler_outputs: SchedulerOutputs | None = Field(
+        default=None, description="The scheduler statistics and outputs"
+    )
