@@ -1,18 +1,20 @@
 """Store the results of a calculation.
 
-This module defines the :class:`.autojob.calculation.calculation.Calculation`,
-:class:`.autojob.calculation.calculation.CalculationInputs`, and
-:class:`.autojob.calculation.calculation.CalculationOutputs` classes. Instances
+This module defines the :class:`~autojob.tasks.calculation.Calculation`,
+:class:`~autojob.tasks.calculation.CalculationInputs`, and
+:class:`~autojob.tasks.calculation.CalculationOutputs` classes. Instances
 of these classes represent the results of a calculation, its inputs, and its
 outputs, respectively.
 
-For building the respective documents from a folder, each class exposes a
-``from_directory()`` method.
+For building the respective documents from a folder, the
+:class:`~autojob.tasks.calculation.Calculation` and
+:class:`~autojob.tasks.calculation.CalculationOutputs` classes are
+:class:`PathLoadable`.
 
 Example:
     .. code-block:: python
 
-        from autojob.calculation.calculation import Calculation
+        from autojob.tasks.calculation import Calculation
 
         src = "path/to/calculation/directory"
         results = Calculation.from_directory(src)
@@ -28,13 +30,18 @@ from typing import ClassVar
 from typing import Self
 
 import jinja2
+import numpy as np
 from pydantic import BaseModel
 from pydantic import ConfigDict
 from pydantic import Field
+from pydantic import FieldSerializationInfo
+from pydantic import SerializerFunctionWrapHandler
+from pydantic import field_serializer
 
 from autojob import SETTINGS
 from autojob.bases.task_base import TaskOutcome
 from autojob.hpc import JobState
+from autojob.hpc import ScheduledMixin
 from autojob.hpc import SchedulerInputs
 from autojob.hpc import SchedulerOutputs
 from autojob.plugins import get_harvester
@@ -104,8 +111,8 @@ class CalculationInputs(BaseModel):
         default={},
         description="The parameters used to configure the ASE calculator",
     )
-    opt_params: dict[str, Any] | None = Field(
-        default=None,
+    opt_params: dict[str, Any] = Field(
+        default={},
         description="The parameters used to configure the ASE optimizer",
     )
     analyses: dict[str, ArgSpec] = Field(
@@ -161,6 +168,27 @@ class CalculationOutputs(BaseModel):
     )
     model_config: ClassVar[ConfigDict] = ConfigDict(extra="allow")
 
+    @field_serializer("calculator_results", mode="wrap")
+    def serialize_calculator_results(
+        self,
+        v: dict[str, Any] | None,
+        _: SerializerFunctionWrapHandler,
+        info: FieldSerializationInfo,
+    ) -> dict[str, Any] | None:
+        """Serialize the calculator results."""
+        if v is None:
+            return None
+
+        if info.mode == "json":
+            listified = {}
+            for k, value in v.items():
+                listified[k] = (
+                    value.tolist() if isinstance(value, np.ndarray) else value
+                )
+            return listified
+
+        return v
+
     # TODO: Add optimizer harvester
     @classmethod
     def from_directory(
@@ -200,18 +228,40 @@ class CalculationOutputs(BaseModel):
         try:
             harvester = get_harvester(calculator)
         except ValueError:
-            logger.info(
+            logger.warning(
                 "Unable to load calculator harvester: %s. Using default harvester",
                 calculator,
             )
-            harvester = get_harvester("default")
+            calculator = "default"
+            harvester = get_harvester(calculator)
 
-        calc_results = harvester(src)
+        try:
+            calc_results = harvester(src)
+        except:  # noqa: E722
+            if strict_mode:
+                raise
+            logger.info(
+                "Unable to load calculator (%s) results from directory: %s.",
+                calculator,
+                src,
+            )
+            calc_results = {}
         analysis_results = {}
 
         for analysis in analyses:
             harvester = get_harvester(analysis)
-            analysis_results[analysis] = harvester(src)
+            try:
+                analysis_results[analysis] = harvester(src)
+            except Exception as err:
+                if strict_mode:
+                    raise
+                logger.warning("%s: %s", str(type(err)), repr(err))
+                logger.warning(
+                    "Unable to load analysis (%s) results from directory: %s.",
+                    analysis,
+                    src,
+                )
+                analysis_results[analysis] = {}
 
         calculation_outputs = cls(
             **calc_results, analysis_results=analysis_results
@@ -223,7 +273,7 @@ class CalculationOutputs(BaseModel):
         return calculation_outputs
 
 
-class Calculation(Task):
+class Calculation(Task, ScheduledMixin):
     """A record representing a calculation."""
 
     calculation_inputs: CalculationInputs = Field(
@@ -233,12 +283,6 @@ class Calculation(Task):
     calculation_outputs: CalculationOutputs | None = Field(
         default=None, description="The calculation outputs"
     )
-    scheduler_inputs: SchedulerInputs = Field(
-        default_factory=SchedulerInputs, description="The scheduler intputs"
-    )
-    scheduler_outputs: SchedulerOutputs | None = Field(
-        default=None, description="The scheduler statistics and outputs"
-    )
 
     # TODO: Write unit test for copying metadata
     @staticmethod
@@ -287,7 +331,7 @@ class Calculation(Task):
 
     @classmethod
     def from_directory(cls, src: str | Path, **kwargs) -> Self:
-        """Generate a ``Calculation`` document from a calculation directory.
+        """Generate a ``Calculation`` document from a task directory.
 
         Args:
             src: The directory of a calculation.
@@ -315,10 +359,12 @@ class Calculation(Task):
         if magic_mode:
             return cls.load_magic(src, strict_mode=strict_mode)
 
+        # Task must be explicitly used (instead of super()) because
+        # Task.from_directory uses returns a type determined by cls
         task = Task.from_directory(
             src=src, strict_mode=strict_mode, magic_mode=False
         )
-        data = task.task_inputs.model_extra.pop("calculation_inputs") or {}
+        data = task.task_inputs.model_extra.pop("calculation_inputs", {})
         calc_inputs = CalculationInputs(**data)
         calc_outputs = CalculationOutputs.from_directory(
             src=src,
@@ -330,7 +376,7 @@ class Calculation(Task):
         sched_outputs = SchedulerOutputs.from_directory(src=src)
 
         if calc_outputs.calculator_results:
-            output_atoms = calc_outputs.calculator_results.get("atoms")
+            output_atoms = calc_outputs.calculator_results.pop("atoms", None)
         else:
             output_atoms = None
 
@@ -344,9 +390,7 @@ class Calculation(Task):
 
         logger.debug("Successfully loaded calculation from directory: %s", src)
         return cls(
-            task_metadata=task.task_metadata,
-            task_inputs=task.task_inputs,
-            task_outputs=task.task_outputs,
+            **task.model_dump(),
             calculation_inputs=calc_inputs,
             calculation_outputs=calc_outputs,
             scheduler_inputs=sched_inputs,
@@ -405,16 +449,14 @@ class Calculation(Task):
         dest: str | Path,
         *,
         additional_data: dict[str, Any] | None = None,
-        **kwargs,  # noqa: ARG002
     ) -> Path:
         """Write the inputs JSON to a file.
 
         Args:
             dest: The directory in which to write the inputs JSON.
             additional_data: A dictionary mapping strings to JSON-serializable
-                values to be merged with the task inputs that will be written
-                to the inputs JSON. Defaults to an empty dictionary.
-            kwargs: Additional keyword arguments.
+                values to be merged with the calculation inputs that will be
+                written to the inputs JSON. Defaults to an empty dictionary.
 
         Returns:
             The filename in which the inputs JSON written.
@@ -432,31 +474,25 @@ class Calculation(Task):
         self,
         dest: str | Path,
         *,
-        template: str = SETTINGS.CALCULATION_SCRIPT_TEMPLATE,  # noqa: ARG002
-        structure_name: str | None = None,
+        additional_data: dict[str, Any] | None = None,
     ) -> Path:
-        """Write the task script used to run the Calculation.
+        """Write the calculation script used to run the task.
 
         Args:
             dest: The directory in which to write the Python script.
-            template: The name of the template to use to write the Python
-                script.
-            structure_name: The filename of the input structure to be read to
-                load the :class:`~ase.atoms.Atoms` object for the calculation.
-                Defaults to the value of the ``"filename"`` key in the input
-                Atoms object, if present. Defaults to the value of
-                ``SETTINGS.INPUT_ATOMS`` otherwise. Take care to ensure that
-                this matches the name of the file to which the structure is
-                written.
+            additional_data: A dictionary mapping strings to JSON-serializable
+                values to be merged with the calculation inputs that will be
+                written to the calculation script. Defaults to an empty
+                dictionary.
 
         Returns:
-            A Path object representing the filename of the written task
+            A Path object representing the filename of the written calculation
             script.
         """
-        dest = Path(dest)
         logger.debug("Writing calculation script to directory: %s", dest)
-        calculator = self.calculation_inputs.calculator
-        parameters = self.calculation_inputs.calc_params
+        additional_data = additional_data or {}
+        context = {**self.model_dump(), "settings": SETTINGS.model_dump()}
+        context |= additional_data or {}
 
         env = jinja2.Environment(
             loader=get_loader(),
@@ -471,24 +507,8 @@ class Calculation(Task):
         )
         filename = Path(dest, self.calculation_inputs.calculation_script)
 
-        if structure_name is None:
-            if (
-                self.task_inputs.atoms is None
-                or self.task_inputs.atoms.info.get("filename") is None
-            ):
-                structure_name = SETTINGS.INPUT_ATOMS_FILE
-            else:
-                structure_name = self.task_inputs.atoms.info["filename"]
-
         with filename.open(mode="x", encoding="utf-8") as file:
-            file.write(
-                to_render.render(
-                    calculator=calculator,
-                    structure=structure_name,
-                    parameters=parameters,
-                    settings=SETTINGS.model_dump(),
-                )
-            )
+            file.write(to_render.render(**context))
 
         logger.debug(
             "Successfully wrote calculation script to file: %s", filename
@@ -500,7 +520,6 @@ class Calculation(Task):
         dest: str | Path,
         *,
         additional_data: dict[str, Any] | None = None,
-        **kwargs,  # noqa: ARG002
     ) -> Path:
         """Write the SLURM input script using the template given.
 
@@ -509,28 +528,20 @@ class Calculation(Task):
             additional_data: A dictionary mapping strings to JSON-serializable
                 values to be merged with the task inputs that will be written
                 to the inputs JSON. Defaults to an empty dictionary.
-            kwargs: additional keyword arguments to be used to
-                render the script template.
 
         Returns:
             A Path representing the filename of the written SLURM script.
         """
-        additional_data = additional_data or {}
-        calculation_inputs = self.calculation_inputs.model_dump()
         raw_sched_inputs = self.scheduler_inputs.model_dump(
             mode="json", exclude_none=True, by_alias=True
         )
-        formatted_sched_inputs = {
-            f"--{k}": v for k, v in raw_sched_inputs.items()
+        inputs = {
+            "scheduler_inputs": {
+                f"--{k}": v for k, v in raw_sched_inputs.items()
+            }
         }
-
-        additional_data = {
-            "calculation_inputs": calculation_inputs,
-            "scheduler_inputs": formatted_sched_inputs,
-            **additional_data,
-        }
-
-        return super().write_task_script(dest, additional_data=additional_data)
+        inputs |= additional_data or {}
+        return super().write_task_script(dest, additional_data=inputs)
 
     def write_inputs(
         self,
