@@ -315,6 +315,11 @@ def fixture_input_atoms(atoms_filename: str) -> Atoms | None:
     return atoms
 
 
+@pytest.fixture(name="task_script")
+def fixture_task_script() -> str:
+    return "task.sh"
+
+
 @pytest.fixture(name="task_script_template")
 def fixture_task_script_template() -> str:
     return "task.sh.j2"
@@ -434,10 +439,10 @@ BUILDING_SCHEDULER_INPUTS = """
 """
 
 
-@pytest.fixture(name="cores", params=[12])
-def fixture_cores(request: pytest.FixtureRequest) -> int:
-    cores: int = request.param
-    return cores
+@pytest.fixture(name="ntasks_per_node", params=[12])
+def fixture_ntasks_per_node(request: pytest.FixtureRequest) -> int:
+    ntasks_per_node: int = request.param
+    return ntasks_per_node
 
 
 @pytest.fixture(name="nodes", params=[1])
@@ -480,7 +485,7 @@ def fixture_mail_user() -> list[str]:
 @pytest.fixture(name="scheduler_inputs")
 def fixture_scheduler_inputs(
     elapsed: timedelta,
-    cores: int,
+    ntasks_per_node: int,
     nodes: int,
     job_name: str,
     partitions: list[Partition],
@@ -493,7 +498,7 @@ def fixture_scheduler_inputs(
         "partition": partitions,
         "mem-per-cpu": mem_per_cpu,
         "nodes": nodes,
-        "ntasks-per-node": cores,
+        "ntasks-per-node": ntasks_per_node,
         "time": elapsed,
         "mail-user": mail_user,
         "mail-type": mail_type,
@@ -573,6 +578,9 @@ def fixture_scheduler_header(
 def fixture_write_scheduler_script(
     calculation: Calculation, task_directory: Path
 ) -> Path:
+    calculation.task_inputs.task_script_template = (
+        SETTINGS.TASK_SCRIPT_TEMPLATE
+    )
     return calculation.write_task_script(task_directory)
 
 
@@ -618,7 +626,7 @@ def fixture_to_calculate() -> list[str]:
 @pytest.fixture(name="calculate")
 def fixture_calculate(
     output_atoms: Atoms, calculator: Calculator, to_calculate: list[str]
-) -> Any:
+) -> None:
     output_atoms.calc = calculator
     calculator.atoms = output_atoms
     calculator.calculate(atoms=output_atoms, properties=to_calculate)
@@ -913,7 +921,6 @@ def fixture_calculation(
     )
     task_class = calculation.__class__.__name__.lower()
     calculation.task_metadata.task_class = task_class
-    calculation.task_inputs.task_script_template = "new_run.sh.j2"
     return calculation
 
 
@@ -1019,9 +1026,7 @@ def fixture_task_directory(
 
 
 @pytest.fixture(name="write_task_inputs")
-def fixture_write_task_inputs(
-    task: Calculation, task_directory: Path
-) -> list[Path]:
+def fixture_write_task_inputs(task: Task, task_directory: Path) -> list[Path]:
     return task.write_inputs(task_directory)
 
 
