@@ -2,7 +2,7 @@ import logging
 
 from click.testing import CliRunner
 
-from autojob.cli.main import main
+from autojob._cli.main import main
 
 logger = logging.getLogger(__name__)
 
