@@ -6,6 +6,7 @@ import pytest
 
 from autojob import SETTINGS
 from autojob.harvest.archive import archive
+from autojob.harvest.archive import archive_json
 from autojob.harvest.harvest import harvest
 
 if TYPE_CHECKING:
@@ -30,13 +31,17 @@ def fixture_strictness() -> Literal["strict", "relaxed", "atomic"]:
     return "atomic"
 
 
+@pytest.fixture(name="task_script")
+def fixture_task_script() -> str:
+    return "gaussian.sh"
+
+
 @pytest.fixture(name="harvested")
 def fixture_harvested(
     strictness: Literal["strict", "relaxed", "atomic"],
     task_directory: Path,
     calculate: None,  # noqa: ARG001
 ) -> "list[TaskBase]":
-    SETTINGS.SLURM_SCRIPT = "gaussian.sh"
     return harvest(task_directory, strictness=strictness)
 
 
@@ -45,6 +50,18 @@ class TestHarvest:
     def test_should_return_harvested(harvested: "list[TaskBase]") -> None:
         assert harvested
 
+    @staticmethod
+    def test_should_harvest_from_archive_in_templated_directory(
+        harvested: "list[TaskBase]", task_directory: Path
+    ) -> None:
+        archive_json(
+            harvested,
+            Path(task_directory, SETTINGS.ARCHIVE_FILE),
+        )
+        renamed = Path(task_directory.parent, "name")
+        task_directory.rename(renamed)
+        assert harvest(renamed, use_cache=True)
+
 
 class TestArchive:
     @staticmethod
