@@ -13,7 +13,6 @@ import pytest
 
 from autojob import SETTINGS
 from autojob.bases.task_base import TASK_GROUP_FIELDS
-from autojob.next import _create_templated_dir_name
 from autojob.next import create_next_step
 from autojob.next import create_task_group_tree
 from autojob.next import create_task_tree
@@ -383,6 +382,27 @@ class TestCreateTaskGroupTree:
         assert task_group_dir.exists()
         assert created == task_group_dir
 
+    # This test is necessary to make sure that the contents temporary directory are not
+    # used to check for naming conflicts conflicts
+    @staticmethod
+    @pytest.mark.parametrize("name_template", ["name_{i}"])
+    def test_should_create_new_task_group_directory_with_conflict_free_name_template(
+        src: Path,
+        task: "TaskBase",
+        dest: Path,
+        name_template: str,
+    ) -> None:
+        Path(src.parent, name_template.format(i=1)).mkdir()
+        created = create_task_group_tree(
+            src=src,
+            task=task,
+            dest=dest,
+            name_template=name_template,
+        )
+        task_group_dir = Path(dest, name_template.format(i=2))
+        assert task_group_dir.exists()
+        assert created == task_group_dir
+
     @staticmethod
     def test_should_raise_value_error_if_task_group_id_is_none(
         src: Path,
@@ -401,82 +421,6 @@ class TestCreateTaskGroupTree:
             )
 
 
-class TestCreateTemplatedDirName:
-    @staticmethod
-    @pytest.fixture(name="task", params=[Task, Calculation])
-    def fixture_task(request: pytest.FixtureRequest) -> "TaskBase":
-        task_class: type[TaskBase] = request.param
-        task: TaskBase = task_class()
-        return task
-
-    @staticmethod
-    @pytest.mark.parametrize("name_template", ["name"])
-    def test_should_name_directory_with_name_template_if_no_template_fields_in_name_template(
-        task: "TaskBase",
-        tmp_path: Path,
-        name_template: str,
-    ) -> None:
-        created = _create_templated_dir_name(
-            name_template=name_template,
-            dest=tmp_path,
-            task=task,
-        )
-        assert created == name_template
-
-    @staticmethod
-    @pytest.mark.parametrize("name_template", ["{structure}-{task_id}"])
-    def test_should_create_directory_name_with_templated_name(
-        task: "TaskBase",
-        tmp_path: Path,
-        name_template: str,
-    ) -> None:
-        created = _create_templated_dir_name(
-            name_template=name_template,
-            dest=tmp_path,
-            task=task,
-        )
-        structure = Path(task.task_inputs.atoms_filename).stem
-        task_id = str(task.task_metadata.task_id)
-        expected = f"{structure}-{task_id}"
-        assert created == expected
-
-    @staticmethod
-    @pytest.mark.parametrize("name_template", ["name_{i}"])
-    def test_should_create_directory_name_with_directory_index(
-        task: "TaskBase",
-        tmp_path: Path,
-        name_template: str,
-    ) -> None:
-        created = _create_templated_dir_name(
-            name_template=name_template,
-            dest=tmp_path,
-            task=task,
-        )
-        expected = "name_1"
-        assert created == expected
-
-    @staticmethod
-    @pytest.mark.parametrize("num_duplicates", range(1, 4))
-    @pytest.mark.parametrize("name_template", ["name"])
-    def test_should_increment_directory_index_for_duplicate_directory(
-        task: "TaskBase",
-        tmp_path: Path,
-        name_template: str,
-        num_duplicates: int,
-    ) -> None:
-        Path(tmp_path, name_template).mkdir()
-        for i in range(num_duplicates):
-            Path(tmp_path, f"{name_template}_{i + 1}").mkdir()
-
-        created = _create_templated_dir_name(
-            name_template=name_template,
-            dest=tmp_path,
-            task=task,
-        )
-        expected = f"{name_template}_{num_duplicates + 1}"
-        assert created == expected
-
-
 @pytest.mark.usefixtures("write_task_group_metadata")
 class TestCreateTaskTree:
     @staticmethod
@@ -544,9 +488,9 @@ class TestCreateTaskTree:
         dest: Path,
     ) -> None:
         created = create_task_tree(
-            src=src,
             task=task,
             dest=dest,
+            src=src,
         )
         assert created.exists()
         assert created.is_dir()
@@ -559,9 +503,9 @@ class TestCreateTaskTree:
         dest: Path,
     ) -> None:
         created = create_task_tree(
-            src=src,
             task=task,
             dest=dest,
+            src=src,
         )
         metadata_file = Path(created, SETTINGS.TASK_METADATA_FILE)
         assert metadata_file.exists()
@@ -573,9 +517,9 @@ class TestCreateTaskTree:
         dest: Path,
     ) -> None:
         created = create_task_tree(
-            src=src,
             task=task,
             dest=dest,
+            src=src,
         )
         metadata_file = Path(created, SETTINGS.TASK_METADATA_FILE)
         with metadata_file.open(mode="r", encoding="utf-8") as file:
@@ -598,15 +542,36 @@ class TestCreateTaskTree:
         name_template: str,
     ) -> None:
         created = create_task_tree(
-            src=src,
             task=task,
             dest=dest,
+            src=src,
             name_template=name_template,
         )
         task_dir = Path(dest, name_template)
         assert task_dir.exists()
         assert created == task_dir
 
+    # This test is necessary to make sure that the contents temporary directory are not
+    # used to check for naming conflicts conflicts
+    @staticmethod
+    @pytest.mark.parametrize("name_template", ["name_{i}"])
+    def test_should_create_new_task_directory_with_conflict_free_name_template(
+        src: Path,
+        task: "TaskBase",
+        dest: Path,
+        name_template: str,
+    ) -> None:
+        Path(src.parent, name_template.format(i=1)).mkdir()
+        created = create_task_tree(
+            task=task,
+            dest=dest,
+            src=src,
+            name_template=name_template,
+        )
+        task_group_dir = Path(dest, name_template.format(i=2))
+        assert task_group_dir.exists()
+        assert created == task_group_dir
+
     @staticmethod
     def test_should_copy_files_to_carry_over_to_new_task_directory(
         src: Path, task: "TaskBase", dest: Path, files_to_carry_over: list[str]
